@@ -3,10 +3,9 @@ from tortoise import Tortoise
 from tortoise.connection import connections
 
 from ..utils import get_path
-from .model import Sub
-from nonebot.log import logger
+from .model import Sub, LiveRoom, Danmaku
 
-sub_dict = {"list":[]}
+sub_dict = {"street_lamp": []}
 
 class Db:
     @classmethod
@@ -15,7 +14,7 @@ class Db:
             "connections":{"danmaku_bot":f"sqlite://{get_path('danmakuBot.sqlite3')}"},
             "apps":{
                 "danmaku_bot_app":{
-                    "models":["nonebot_plugin_blive_danmaku.database.model"],
+                    "models":["nonebot_plugin_blive_danmaku.database.model", "aerich.models"],
                     "default_connection":"danmaku_bot"
                 }
             }
@@ -56,13 +55,43 @@ class Db:
         return res
 
     @classmethod
-    def get_sub_list(cls):
-        return sub_dict["list"]
-
+    def get_sub_list(cls, key):
+        return sub_dict[key]
+ 
     @classmethod
     async def update_sub_list(cls):
         subs = Sub.all()
-        sub_dict["list"] = list(set([sub.uid async for sub in subs if sub.street_lamp]))
+        sub_dict["street_lamp"] = list(set([sub.uid async for sub in subs if sub.street_lamp]))
+    
+    @classmethod
+    async def get_rooms(cls, **kwargs):
+        res = await LiveRoom.get(**kwargs)
+        return res
+    
+    @classmethod
+    async def get_room(cls, **kwargs):
+        res = await LiveRoom.get(**kwargs).first()
+        return res
+    
+    @classmethod
+    async def get_danmaku_by_rid(cls, room_id):
+        res = await Danmaku.get(room_id=room_id).order_by("-create_time")
+        return res
+    
+    @classmethod
+    async def add_room(cls, **kwargs):
+        res = await LiveRoom.add(**kwargs)
+        return res
+    
+    @classmethod
+    async def update_room(cls, conf, switch, **kwargs):
+        res = await LiveRoom.update(kwargs, **{conf: switch})
+        return res
+    
+    @classmethod
+    async def add_danmaku(cls, **kwargs):
+        res = await Danmaku.add(**kwargs)
+        return res
 
 
 get_driver().on_startup(Db.init)
